export type FilterFunction = (filename: string) => boolean;
export interface DoxicityConfig {
    source: string;
    destination: string;
    baseUrl: string;
    layouts: string;
    partials: string;
    assets: string;
    sharedStyles: string;
    sharedScripts: string;
    data: {
        [key: string]: unknown;
    };
    cleanBeforePublishing: boolean;
    plugins: DoxicityPlugin[];
    helpers: DoxicityHelper[];
    filterPages: FilterFunction;
    pageExtension: string;
}
export interface DoxicityHelper {
    name: string;
    callback: (args: unknown) => string;
}
export interface DoxicityPage {
    sourceFile: string;
    destinationFile: string;
    pathname: string;
    data: Record<string, unknown>;
}
export interface DoxicityPlugin {
    name: string;
    scripts?: (config: DoxicityConfig) => string | Promise<string>;
    styles?: (config: DoxicityConfig) => string | Promise<string>;
    transform?: (doc: Document, page: DoxicityPage, config: DoxicityConfig) => Document | Promise<Document>;
    afterTransform?: (html: string, page: DoxicityPage, config: DoxicityConfig) => string | Promise<string>;
    afterAll?: (result: DoxicityPublishResult, config: DoxicityConfig) => void | Promise<void>;
}
export interface DoxicityPublishOptions {
    copyAssets: boolean;
}
export interface DoxicityPublishResult {
    pages: DoxicityPage[];
    assets: string[];
    timeToPublish: number;
    timeToCopyAssets: number;
}
export interface DoxicityCopyAssetsResult {
    assets: string[];
    timeToCopy: number;
}
